==> haskell-hourglass-0.2.12-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hourglass.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hourglass
version: 0.2.12
id: hourglass-0.2.12-CF3fjRUS5UFExIFHMdwae3
key: hourglass-0.2.12-CF3fjRUS5UFExIFHMdwae3
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-hourglass
synopsis: simple performant time related library
description:
    Simple time library focusing on simple but powerful and performant API
    .
    The backbone of the library are the Timeable and Time type classes.
    .
    Each Timeable instances can be converted to type that has a Time instances,
    and thus are different representations of current time.
category: Time
abi: e39fd507dcf416621bcddc632d4e73b6
exposed: True
exposed-modules:
    Data.Hourglass Data.Hourglass.Compat Data.Hourglass.Epoch
    Data.Hourglass.Types System.Hourglass Time.Compat Time.System
    Time.Types
hidden-modules: Data.Hourglass.Time Data.Hourglass.Format
                Data.Hourglass.Diff Data.Hourglass.Local Data.Hourglass.Calendar
                Data.Hourglass.Zone Data.Hourglass.Internal Data.Hourglass.Utils
                Data.Hourglass.Internal.Unix
import-dirs: /usr/lib/ghc-8.6.3/site-local/hourglass-0.2.12
library-dirs: /usr/lib/ghc-8.6.3/site-local/hourglass-0.2.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/hourglass-0.2.12
hs-libraries: HShourglass-0.2.12-CF3fjRUS5UFExIFHMdwae3
depends:
    base-4.12.0.0 deepseq-1.4.4.0
haddock-interfaces: /usr/share/doc/haskell-hourglass/html/hourglass.haddock
haddock-html: /usr/share/doc/haskell-hourglass/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hourglass-0.2.12-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hourglass.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hourglass
version: 0.2.12
id: hourglass-0.2.12-4Si5cuysh1XI8xL9F9SZUc
key: hourglass-0.2.12-4Si5cuysh1XI8xL9F9SZUc
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-hourglass
synopsis: simple performant time related library
description:
    Simple time library focusing on simple but powerful and performant API
    .
    The backbone of the library are the Timeable and Time type classes.
    .
    Each Timeable instances can be converted to type that has a Time instances,
    and thus are different representations of current time.
category: Time
abi: 6b997adb935bcc78dfe5ee04835e5e43
exposed: True
exposed-modules:
    Data.Hourglass Data.Hourglass.Compat Data.Hourglass.Epoch
    Data.Hourglass.Types System.Hourglass Time.Compat Time.System
    Time.Types
hidden-modules: Data.Hourglass.Time Data.Hourglass.Format
                Data.Hourglass.Diff Data.Hourglass.Local Data.Hourglass.Calendar
                Data.Hourglass.Zone Data.Hourglass.Internal Data.Hourglass.Utils
                Data.Hourglass.Internal.Unix
import-dirs: /usr/lib/ghc-8.6.4/site-local/hourglass-0.2.12
library-dirs: /usr/lib/ghc-8.6.4/site-local/hourglass-0.2.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hourglass-0.2.12
hs-libraries: HShourglass-0.2.12-4Si5cuysh1XI8xL9F9SZUc
depends:
    base-4.12.0.0 deepseq-1.4.4.0
haddock-interfaces: /usr/share/doc/haskell-hourglass/html/hourglass.haddock
haddock-html: /usr/share/doc/haskell-hourglass/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
